==> nextcloud-29.0.5.tgz: nextcloud/apps/oauth2/l10n/nb.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Din klient er ikke autorisert til å koble til. Vennligst informer din klients administrator.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "URL for videresending må være en fullstendig URL. For eksempel https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Tillater OAuth2-kompatibel autentisering fra andre nettapplikasjoner.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2-appen gir administratorer mulighet til å konfigurere den innebygde arbeidsflyten for autentisering til å også tillate OAuth2-kompatibel autentisering fra andre nett-applikasjoner.",
    "OAuth 2.0 clients" : "OAuth 2.0-klienter",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 gir eksterne tjenester tillatelse til å be om tilgang til {instanceName}.",
    "Name" : "Navn",
    "Redirection URI" : "Videresendings-URI",
    "Client Identifier" : "Klient-identifikator",
    "Secret key" : "Hemmelig nøkkel",
    "Delete client" : "Slett klient",
    "Add client" : "Legg til klient",
    "Add" : "Legg til",
    "Delete" : "Slett",
    "Show client secret" : "Vis klients hemmelighet",
    "Hide client secret" : "Skjul klienthemmelighet"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.12.tgz: nextcloud/apps/oauth2/l10n/nb.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Din klient er ikke autorisert til å koble til. Vennligst informer din klients administrator.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "URL for videresending må være en fullstendig URL. For eksempel https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Tillater OAuth2-kompatibel autentisering fra andre nettapplikasjoner.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2-appen gir administratorer mulighet til å konfigurere den innebygde arbeidsflyten for autentisering til å også tillate OAuth2-kompatibel autentisering fra andre nett-applikasjoner.",
    "OAuth 2.0 clients" : "OAuth 2.0-klienter",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 gir eksterne tjenester tillatelse til å be om tilgang til {instanceName}.",
    "Name" : "Navn",
    "Redirection URI" : "Videresendings-URI",
    "Client Identifier" : "Klient-identifikator",
    "Secret key" : "Hemmelig nøkkel",
    "Delete client" : "Slett klient",
    "Make sure you store the secret key, it cannot be recovered." : "Pass på at du oppbevarer den hemmelige nøkkelen, den kan ikke gjenopprettes.",
    "Add client" : "Legg til klient",
    "Add" : "Legg til",
    "Show client secret" : "Vis klients hemmelighet",
    "Hide client secret" : "Skjul klienthemmelighet",
    "Delete" : "Slett"
},
"nplurals=2; plural=(n != 1);");
